# odepack

Click here to see the number of accesses to this library.

    file	odepack/demo.f  odepack/demo.f plus dependencies
    for	example program for the routines in the odepack library
    prec	double

    file	odepack/doc
    for	document describing the set of routines in the odepack library, recommended reading
    prec	double

    file	odepack/lsoda.f  odepack/lsoda.f plus dependencies
    for	ODEs of the form dy/dt=f, automatic selection between stiff and nonstiff methods
    gams	I1a1b I1a2
    prec	double

    file	odepack/lsodar.f  odepack/lsodar.f plus dependencies
    for	a variant of (odepack/lsoda) for ODEs of the form dy/dt=f for stiff and nostiff odes with root finding for a set of functions, usefule for stopping conditions or switching forms of the function f
    gams	I1a1b I1a2
    prec	double

    file	odepack/lsode.f  odepack/lsode.f plus dependencies
    for	stiff and nonstiff systems of ODEs of the form dy/dt = f, Adams method or Backward-Differentiation Formula, user supplied or difference quotient Jacobians
    gams	I1a1b I1a2
    prec	double

    file	odepack/lsodes.f  odepack/lsodes.f plus dependencies
    for	stiff and nonstiff ODEs of the form dy/dt=f, general sparse Jacobian
    gams	I1a1b I1a2
    prec	double

    file	odepack/lsodi.f  odepack/lsodi.f plus dependencies
    for	systems of ODEs of the form A(t,y) dy/dt = g(t,y), this can include differential-algebraic systems
    gams	I1a1b I1a2
    prec	double

    file	odepack/lsoibt.f  odepack/lsoibt.f plus dependencies
    for	systems of ODEs of the form A(t,y) dy/dt = g(t,y), all matrices involved are assumed to be block-tridiagonal
    gams	I1a1b I1a2
    prec	double

    file	odepack/adjlr.f  odepack/adjlr.f plus dependencies

    file	odepack/aigbt.f  odepack/aigbt.f plus dependencies

    file	odepack/ainvg.f  odepack/ainvg.f plus dependencies

    file	odepack/blkdta000.f  odepack/blkdta000.f plus dependencies

    file	odepack/bnorm.f  odepack/bnorm.f plus dependencies

    file	odepack/cdrv.f  odepack/cdrv.f plus dependencies

    file	odepack/cfode.f  odepack/cfode.f plus dependencies

    file	odepack/cntnzu.f  odepack/cntnzu.f plus dependencies

    file	odepack/decbt.f  odepack/decbt.f plus dependencies

    file	odepack/ewset.f  odepack/ewset.f plus dependencies

    file	odepack/fnorm.f  odepack/fnorm.f plus dependencies

    file	odepack/intdy.f  odepack/intdy.f plus dependencies

    file	odepack/iprep.f  odepack/iprep.f plus dependencies

    file	odepack/jgroup.f  odepack/jgroup.f plus dependencies

    file	odepack/md.f  odepack/md.f plus dependencies

    file	odepack/mdi.f  odepack/mdi.f plus dependencies

    file	odepack/mdm.f  odepack/mdm.f plus dependencies

    file	odepack/mdp.f  odepack/mdp.f plus dependencies

    file	odepack/mdu.f  odepack/mdu.f plus dependencies

    file	odepack/nnfc.f  odepack/nnfc.f plus dependencies

    file	odepack/nnsc.f  odepack/nnsc.f plus dependencies

    file	odepack/nntc.f  odepack/nntc.f plus dependencies

    file	odepack/nroc.f  odepack/nroc.f plus dependencies

    file	odepack/nsfc.f  odepack/nsfc.f plus dependencies

    file	odepack/odrv.f  odepack/odrv.f plus dependencies

    file	odepack/pjibt.f  odepack/pjibt.f plus dependencies

    file	odepack/prep.f  odepack/prep.f plus dependencies

    file	odepack/prepj.f  odepack/prepj.f plus dependencies

    file	odepack/prepji.f  odepack/prepji.f plus dependencies

    file	odepack/prja.f  odepack/prja.f plus dependencies

    file	odepack/prjs.f  odepack/prjs.f plus dependencies

    file	odepack/rchek.f  odepack/rchek.f plus dependencies

    file	odepack/roots.f  odepack/roots.f plus dependencies

    file	odepack/slsbt.f  odepack/slsbt.f plus dependencies

    file	odepack/slss.f  odepack/slss.f plus dependencies

    file	odepack/solbt.f  odepack/solbt.f plus dependencies

    file	odepack/solsy.f  odepack/solsy.f plus dependencies

    file	odepack/srcar.f  odepack/srcar.f plus dependencies

    file	odepack/srcma.f  odepack/srcma.f plus dependencies

    file	odepack/srcms.f  odepack/srcms.f plus dependencies

    file	odepack/srcom.f  odepack/srcom.f plus dependencies

    file	odepack/sro.f  odepack/sro.f plus dependencies

    file	odepack/stoda.f  odepack/stoda.f plus dependencies

    file	odepack/stode.f  odepack/stode.f plus dependencies

    file	odepack/stodi.f  odepack/stodi.f plus dependencies

    file	odepack/vmnorm.f  odepack/vmnorm.f plus dependencies

    file	odepack/vnorm.f  odepack/vnorm.f plus dependencies

    file	odepack/xerrwv.f  odepack/xerrwv.f plus dependencies

    file	odepack/xsetf.f  odepack/xsetf.f plus dependencies

    file	odepack/xsetun.f  odepack/xsetun.f plus dependencies

    file	odepack/readme